@@ -2,16 +2,22 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
+from typing import List, Union, Dict, Optional
+from datetime import datetime
+
+from mozanalysis.bq import BigQueryContext
+from mozanalysis.experiment import TimeSeriesResult
+from mozanalysis.metrics import Metric
+from mozanalysis.segments import Segment
+from mozanalysis.sizing import HistoricalTarget
+from mozanalysis.utils import get_time_intervals
+
 from scipy.stats import norm
 from math import pi
 from statsmodels.stats.power import tt_ind_solve_power, zt_ind_solve_power
-from mozanalysis.bq import BigQueryContext
-from mozanalysis.experiment import TimeSeriesResult
 from statsmodels.stats.proportion import samplesize_proportions_2indep_onetail
 import numpy as np
 import pandas as pd
-from mozanalysis.metrics import Metric
-from typing import List, Union, Dict
 import matplotlib.pyplot as plt
 
 
@@ -50,8 +56,8 @@ def sample_size_curves(
     Returns:
         A dictionary of pd.DataFrame objects. An item in the dictionary is
         created for each metric in metric_list, containing a DataFrame of sample
-        size, population size, and population proportion at each value of the iterable
-        parameter.
+        size per branch, number of clients that satisfied targeting, and population
+        proportion per branch at each value of the iterable parameter.
     """
 
     params = {"effect_size": effect_size, "power": power, "alpha": alpha}
@@ -113,8 +119,8 @@ def difference_of_proportions_sample_size_calc(
 
     Returns:
         A dictionary. Keys in the dictionary are the metrics column names from
-        the DataFrame; values are the required sample size to achieve the
-        desired power for that metric.
+        the DataFrame; values are the required sample size per branch to achieve
+        the desired power for that metric.
     """
 
     def _get_sample_size_col(col):
@@ -133,9 +139,9 @@ def difference_of_proportions_sample_size_calc(
         sample_size = _get_sample_size_col(col)
         pop_percent = 100.0 * (sample_size / len(df))
         results[col] = {
-            "sample_size": sample_size,
-            "population_size": len(df),
-            "population_percent": pop_percent,
+            "sample_size_per_branch": sample_size,
+            "population_percent_per_branch": pop_percent,
+            "number_of_clients_targeted": len(df),
         }
     return results
 
@@ -171,8 +177,8 @@ def z_or_t_ind_sample_size_calc(
 
     Returns:
         A dictionary. Keys in the dictionary are the metrics column names from
-        the DataFrame; values are the required sample size to achieve the
-        desired power for that metric.
+        the DataFrame; values are the required sample size per branch to achieve
+        the desired power for that metric.
     """
     tests = {
         "normal": zt_ind_solve_power,
@@ -196,9 +202,9 @@ def z_or_t_ind_sample_size_calc(
         sample_size = _get_sample_size_col(col)
         pop_percent = 100.0 * (sample_size / len(df))
         results[col] = {
-            "sample_size": sample_size,
-            "population_size": len(df),
-            "population_percent": pop_percent,
+            "sample_size_per_branch": sample_size,
+            "population_percent_per_branch": pop_percent,
+            "number_of_clients_targeted": len(df),
         }
     return results
 
@@ -247,8 +253,8 @@ def empirical_effect_size_sample_size_calc(
 
     Returns:
         A dictionary. Keys in the dictionary are the metrics column names from
-        the DataFrame; values are the required sample size to achieve the
-        desired power for that metric.
+        the DataFrame; values are the required sample size per branch to achieve
+        the desired power for that metric.
     """
 
     def _mann_whitney_solve_sample_size_approximation(
@@ -317,7 +323,7 @@ def empirical_effect_size_sample_size_calc(
         m.name: {
             "effect_size": effect_size[m.name],
             "std_dev": std[m.name],
-            "sample_size": _mann_whitney_solve_sample_size_approximation(
+            "sample_size_per_branch": _mann_whitney_solve_sample_size_approximation(
                 effect_size=effect_size[m.name]["value"],
                 std=std[m.name]["value"],
                 power=power,
@@ -329,12 +335,12 @@ def empirical_effect_size_sample_size_calc(
     }
 
     for k in size_dict.keys():
-        size_dict[k]["population_size"] = pop_size
-        size_dict[k]["population_percent"] = 100.0 * (
-            size_dict[k]["sample_size"] / pop_size
+        size_dict[k]["number_of_clients_targeted"] = pop_size
+        size_dict[k]["population_percent_per_branch"] = 100.0 * (
+            size_dict[k]["sample_size_per_branch"] / pop_size
         )
 
-    return size_dict
+    return size_dict  # TODO: add option to return a DataFrame
 
 
 def poisson_diff_solve_sample_size(
@@ -366,8 +372,8 @@ def poisson_diff_solve_sample_size(
 
     Returns:
         A dictionary. Keys in the dictionary are the metrics column names from
-        the DataFrame; values are the required sample size to achieve the
-        desired power for that metric.
+        the DataFrame; values are the required sample size per branch to achieve
+        the desired power for that metric.
     """
 
     def _get_sample_size_col(col):
@@ -390,8 +396,113 @@ def poisson_diff_solve_sample_size(
         sample_size = _get_sample_size_col(col)
         pop_percent = 100.0 * (sample_size / len(df))
         results[col] = {
-            "sample_size": sample_size,
-            "population_size": len(df),
-            "population_percent": pop_percent,
+            "sample_size_per_branch": sample_size,
+            "population_percent_per_branch": pop_percent,
+            "number_of_clients_targeted": len(df),
         }
     return results
+
+
+def variable_enrollment_length_sample_size_calc(
+    bq_context: BigQueryContext,
+    start_date: Union[str, datetime],
+    max_enrollment_days: int,
+    analysis_length: int,
+    metric_list: List[Metric],
+    target_list: List[Segment],
+    variable_window_length: int = 7,
+    experiment_name: Optional[str] = "",
+    app_id: Optional[str] = "",
+    to_pandas: bool = True,
+    **sizing_kwargs,
+) -> Dict[str, Union[Dict[str, int], pd.DataFrame]]:
+    """
+    Sample size calculation over a variable enrollment window. This function
+    will fetch a DataFrame with metrics defined in metric_list for a target
+    population defined in the target_list over an enrollment window of length
+    max_enrollment_days. Sample size calculation is performed
+    using clients enrolled in the first variable_window_length dates in
+    that max enrollment window; that window is incrementally widened by
+    the variable window length and sample size calculation performed again,
+    until the last enrollment date is reached.
+
+    Args:
+        bq_context: A mozanalysis.bq.BigQueryContext object that handles downloading
+            data from BigQuery.
+        start_date (str or datetime in %Y-%m-%d format): First date of enrollment for
+            sizing job.
+        max_enrollment_days (int): Maximum number of dates to consider for the
+            enrollment period for the experiment in question.
+        analysis_length (int): Number of days to record metrics for each client
+            in the experiment in question.
+        metric_list (list of mozanalysis.metrics.Metric): List of metrics
+            used to construct the results df from HistoricalTarget. The names
+            of these metrics are used to return results for sample size
+            calculation for each.
+        target_list (list of mozanalysis.segments.Segment): List of segments
+            used to identify clients to include in the study.
+        variable_window_length (int): Length of the intervals used to extend
+            the enrollment period incrementally. Sample sizes are recalculated over
+            each variable enrollment period.
+        experiment_name (str): Optional name used to name the target and metric
+            tables in BigQuery.
+        app_id (str): Application that experiment will be run on.
+        **sizing_kwargs: Arguments to pass to z_or_t_ind_sample_size_calc
+
+    Returns:
+        A dictionary. Keys in the dictionary are the metrics column names from
+        the DataFrame; values are the required sample size per branch to achieve
+        the desired power for that metric.
+    """
+
+    if variable_window_length > max_enrollment_days:
+        raise ValueError(
+            "Enrollment window length is larger than the max enrollment length."
+        )
+
+    ht = HistoricalTarget(
+        start_date=start_date,
+        analysis_length=analysis_length,
+        num_dates_enrollment=max_enrollment_days,
+        experiment_name=experiment_name,
+        app_id=app_id,
+    )
+
+    df = ht.get_single_window_data(
+        bq_context=bq_context, metric_list=metric_list, target_list=target_list
+    )
+
+    interval_end_dates = get_time_intervals(
+        start_date,
+        variable_window_length,
+        max_enrollment_days,
+    )
+
+    def _for_interval_sample_size_calculation(i):
+
+        df_interval = df.loc[df["enrollment_date"] < interval_end_dates[i]]
+        res = z_or_t_ind_sample_size_calc(
+            df=df_interval, metrics_list=metric_list, test="t", **sizing_kwargs
+        )
+        final_res = {}
+        for key in res.keys():
+            final_res[key] = {
+                "enrollment_end_date": interval_end_dates[i],
+                **res[key],
+            }
+
+        return final_res
+
+    results_dict = {}
+    for m in metric_list:
+        results_dict[m.name] = []
+
+    for i in range(len(interval_end_dates)):
+        res = _for_interval_sample_size_calculation(i)
+        for m in metric_list:
+            results_dict[m.name].append(res[m.name])
+
+    for m in results_dict.keys():
+        results_dict[m] = pd.DataFrame(results_dict[m])
+
+    return results_dict
