@@ -4,10 +4,12 @@ from cheap_lint import sql_lint
 import mozanalysis.metrics.desktop as mad
 import mozanalysis.metrics.fenix
 import mozanalysis.metrics.firefox_ios
+import mozanalysis.metrics.klar_ios
+import mozanalysis.metrics.klar_android
 import mozanalysis.segments.desktop as msd
-from mozanalysis.experiment import AnalysisBasis, AnalysisWindow, Experiment, TimeLimits
+from mozanalysis.experiment import AnalysisWindow, Experiment, TimeLimits
 from mozanalysis.exposure import ExposureSignal
-from mozanalysis.metrics import Metric
+from mozanalysis.metrics import Metric, AnalysisBasis, DataSource
 from mozanalysis.segments import Segment, SegmentDataSource
 
 
@@ -295,7 +297,7 @@ def test_megaquery_not_detectably_malformed():
     sql_lint(enrollments_sql)
 
     metrics_sql = exp.build_metrics_query(
-        metric_list=[m for m in mad.__dict__.values() if isinstance(m, mad.Metric)],
+        metric_list=[m for m in mad.__dict__.values() if isinstance(m, Metric)],
         time_limits=tl,
         enrollments_table="enrollments",
     )
@@ -315,14 +317,14 @@ def test_segments_megaquery_not_detectably_malformed():
 
     enrollments_sql = exp.build_enrollments_query(
         time_limits=tl,
-        segment_list=[s for s in msd.__dict__.values() if isinstance(s, msd.Segment)],
+        segment_list=[s for s in msd.__dict__.values() if isinstance(s, Segment)],
         enrollments_query_type="normandy",
     )
 
     sql_lint(enrollments_sql)
 
     metrics_sql = exp.build_metrics_query(
-        metric_list=[m for m in mad.__dict__.values() if isinstance(m, mad.Metric)],
+        metric_list=[m for m in mad.__dict__.values() if isinstance(m, Metric)],
         time_limits=tl,
         enrollments_table="enrollments",
     )
@@ -737,3 +739,86 @@ def test_metrics_query_with_exposure_signal():
 
     assert "DATE_ADD('2019-01-01', INTERVAL 0 DAY)" in metrics_sql
     assert "DATE_ADD('2019-01-08', INTERVAL 0 DAY)" in metrics_sql
+
+
+def test_resolve_metric_slugs():
+    exp = Experiment("slug", "2019-01-01", 8, "org_mozilla_fenix", "fenix")
+
+    tl = TimeLimits.for_ts(
+        first_enrollment_date="2019-01-01",
+        last_date_full_data="2019-03-01",
+        time_series_period="weekly",
+        num_dates_enrollment=8,
+    )
+
+    metrics_sql = exp.build_metrics_query(
+        metric_list=["baseline_ping_count"],
+        time_limits=tl,
+        enrollments_table="enrollments",
+    )
+
+    sql_lint(metrics_sql)
+
+    assert "baseline" in metrics_sql
+
+
+def test_resolve_invalid_metric_slugs():
+    exp = Experiment("slug", "2019-01-01", 8, "org_mozilla_fenix", "fenix")
+
+    tl = TimeLimits.for_ts(
+        first_enrollment_date="2019-01-01",
+        last_date_full_data="2019-03-01",
+        time_series_period="weekly",
+        num_dates_enrollment=8,
+    )
+
+    with pytest.raises(Exception):
+        exp.build_metrics_query(
+            metric_list=["not_exist"],
+            time_limits=tl,
+            enrollments_table="enrollments",
+        )
+
+
+def test_resolve_invalid_app_name():
+    exp = Experiment("slug", "2019-01-01", 8, "unknown", "unknown")
+
+    tl = TimeLimits.for_ts(
+        first_enrollment_date="2019-01-01",
+        last_date_full_data="2019-03-01",
+        time_series_period="weekly",
+        num_dates_enrollment=8,
+    )
+
+    with pytest.raises(Exception):
+        exp.build_metrics_query(
+            metric_list=["baseline_ping_count"],
+            time_limits=tl,
+            enrollments_table="enrollments",
+        )
+
+
+def test_resolve_missing_column_names():
+    test_ds = DataSource(
+        name="test_ds",
+        from_expr="SELECT client_id FROM test_set",
+        client_id_column=None,
+        submission_date_column=None,
+    )
+
+    test_metric = Metric(name="test_metric", data_source=test_ds, select_expr="")
+
+    tl = TimeLimits.for_single_analysis_window(
+        first_enrollment_date="2022-01-01",
+        last_date_full_data="2022-01-13",
+        analysis_start_days=0,
+        analysis_length_dates=7,
+    )
+
+    test_exp = Experiment(experiment_slug="test_exp", start_date="2022-01-01")
+
+    metric_sql = test_exp.build_metrics_query(
+        metric_list=[test_metric], time_limits=tl, enrollments_table="test_table"
+    )
+
+    assert "None" not in metric_sql
